# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel
from pydantic import AnyUrl, Field

from telus_bulk.models.tmf_645.order_item_action_type import OrderItemActionType


class RelatedServiceOrderItem(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    RelatedServiceOrderItem - a model defined in OpenAPI

        item_id: The item_id of this RelatedServiceOrderItem.
        role: The role of this RelatedServiceOrderItem [Optional].
        service_order_href: The service_order_href of this RelatedServiceOrderItem [Optional].
        service_order_id: The service_order_id of this RelatedServiceOrderItem.
        item_action: The item_action of this RelatedServiceOrderItem [Optional].
        base_type: The base_type of this RelatedServiceOrderItem [Optional].
        schema_location: The schema_location of this RelatedServiceOrderItem [Optional].
        type: The type of this RelatedServiceOrderItem [Optional].
        referred_type: The referred_type of this RelatedServiceOrderItem [Optional].
    """

    item_id: str
    role: Optional[str] = None
    service_order_href: Optional[str] = None
    service_order_id: str
    item_action: Optional[OrderItemActionType] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias="@type")
    referred_type: Optional[str] = Field(default=None, alias="@referredType")


RelatedServiceOrderItem.update_forward_refs()



from typing import Optional

from fastapi_camelcase import CamelModel
from pydantic import Field


class ZoneAttributes(CamelModel):
    coid: Optional[str] = Field(None, alias='COID')
    co_clli: Optional[str] = Field(None, alias='CO_CLLI')
    utc_offset: Optional[str] = Field(None, alias='UTC_OFFSET')
    time_zone_name: Optional[str] = Field(None, alias='TIME_ZONE_NAME')
    time_zone_abbreviations: Optional[str] = Field(
        None, alias='TIME_ZONE_ABBREVIATIONS'
    )
    time_zone_regions: Optional[str] = Field(None, alias='TIME_ZONE_REGIONS')
    e911_municipality: Optional[str] = Field(None, alias='E911_MUNICIPALITY')




from typing import Any, List, Dict, Optional, Literal

from fastapi_camelcase import CamelModel
from pydantic import Field

from telus_bulk.models.ams.coordinate import Coordinate
from telus_bulk.models.ams.e911_address import E911Address
from telus_bulk.models.ams.fms_address import FmsAddress
from telus_bulk.models.ams.reference_id import ReferenceId
from telus_bulk.models.ams.reference_ids import ReferenceIds
from telus_bulk.models.ams.zone_info_item import ZoneInfoItem
from telus_bulk.models.worker_job.place import PlaceAMS


class AddressDetailModel(CamelModel):
    address_id: str
    address_type: str
    reference_id: ReferenceId
    reference_ids: ReferenceIds
    unit: Any
    floor: Any
    street_number_prefix: Any
    street_number: str
    street_number_suffix: Any
    dir_prefix: Any
    street_type_prefix: Any
    street_name: str
    street_type_suffix: Any
    dir_suffix: Any
    city: str
    province: str
    postal_code: Optional[str] = Field(default="N/A")
    country: Optional[Literal["USA", "CAN"]] = Field(default="CAN")
    coid: str
    serviceable: str
    serviceable_code: str
    building_type: str
    premise_count_flag: Any
    premise_count_date: Any
    postal_code_updt_ts: Any
    res_line_count: str
    bus_line_count: str
    mdu_sfu_count: str
    project_sub_type: Any
    first_nation_ind: str
    exception_code: Any
    nap_addr_assoc: Any
    coordinate: Coordinate
    zone_info: List[ZoneInfoItem]
    fms_address: FmsAddress
    e911_address: E911Address
    tag: List
    location_comments: Dict[str, Any]

    def to_csq_item(self) -> PlaceAMS:
        return PlaceAMS(
            id=self.address_id,
            city=self.city,
            country=self.country,
            postcode=self.postal_code,
            state_or_province=self.province,
            street_dir=self.dir_prefix,
            street_name=self.street_name,
            street_nr=self.street_number,
            street_type=self.street_type_prefix,
            floor=self.floor,
            unit=self.unit,
            address_type=self.address_type,
            coordinate=self.coordinate,
        )



from typing import Optional
from fastapi_camelcase import CamelModel
from pydantic import Field


class FmsAddress(CamelModel):
    sa_no: Optional[str] = Field(..., alias="saNo")
    resc_cd: Optional[str] = Field(..., alias="rescCd")
    sa_house: Optional[str] = Field(..., alias="saHouse")
    sa_street_name: Optional[str] = Field(..., alias="saStreetName")
    sa_city_province_code: Optional[str] = Field(..., alias="saCityProvinceCode")
    sa_postal_code: Optional[str] = Field(default="N/A", alias="saPostalCode")
    sa_clli_code: Optional[str] = Field(..., alias="saCLLICode")
    serv_coid: Optional[str] = Field(..., alias="servCoid")
    sa_clli_prov_cd: Optional[str] = Field(..., alias="saClliProvCd")



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401
from pydantic import AnyUrl, Field

from telus_bulk.models.tmf_645.service_category_ref import ServiceCategoryRef
from telus_bulk.models.tmf_645.service_ref_or_value import ServiceRefOrValue


class ServiceQualificationItem(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    ServiceQualificationItem - a model defined in OpenAPI

        id: The id of this ServiceQualificationItem [Optional].
        expected_activation_date: The expected_activation_date of this ServiceQualificationItem [Optional].
        expected_service_availability_date: The expected_service_availability_date of this ServiceQualificationItem [Optional].
        expiration_date: The expiration_date of this ServiceQualificationItem [Optional].
        category: The category of this ServiceQualificationItem [Optional].
        service: The service of this ServiceQualificationItem [Optional].
        base_type: The base_type of this ServiceQualificationItem [Optional].
        schema_location: The schema_location of this ServiceQualificationItem [Optional].
        type: The type of this ServiceQualificationItem [Optional].
    """

    id: Optional[str] = None
    expected_activation_date: Optional[datetime] = None
    expected_service_availability_date: Optional[datetime] = None
    expiration_date: Optional[datetime] = None
    category: Optional[ServiceCategoryRef] = None
    service: Optional[ServiceRefOrValue] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias="@type")


ServiceQualificationItem.update_forward_refs()



from __future__ import annotations
from typing import Optional
from fastapi_camelcase import CamelModel
from pydantic import Field


class ServiceSpecification(CamelModel):
    id: Optional[str] = Field(default=None)
    href: Optional[str] = Field(default=None)
    name: str
    version: Optional[str] = Field(default=None)
    _type: Optional[str] = Field(default="ServiceSpecification", alias="@type")
